@@ -1,4 +1,4 @@
-from fastapi_plus.service.base import BaseService
+from bztt_fastapi_plus1.service.base import BaseService
 
 from ..dao.demo import DemoDao
 from ..model.demo import Demo
