@@ -37,8 +37,9 @@ def get_auth_data_by_token(token: str, ex: int = None):
     payload = {}
     my_jwt1 = my_jwt()
     try:
-        payload, msg = my_jwt1.validate_token_log(token)
+        payload, msg = my_jwt1.validate_token(token)
     except:
+        print("鉴权失败")
         pass
 
     return payload
